# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    formats = (
        '02-####-####',
        '031-###-####',
        '032-###-####',
        '033-###-####',
        '041-###-####',
        '042-###-####',
        '043-###-####',
        '044-###-####',
        '051-###-####',
        '052-###-####',
        '053-###-####',
        '054-###-####',
        '055-###-####',
        '061-###-####',
        '062-###-####',
        '063-###-####',
        '064-7##-####',
        '010-####-####',
        '011-###-####',
        '016-###-####',
        '017-###-####',
        '018-###-####',
        '019-###-####',
        '070-####-####',
    )
